"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var utils_1 = require("./utils");
var fs = require("fs-extra");
var d = require("debug");
var pkg = fs.readJsonSync(process.cwd() + '/package.json');
var debug = d('cli');
var VOY_FIELDS;
(function (VOY_FIELDS) {
    VOY_FIELDS["dep"] = "dependencies";
    VOY_FIELDS["dev"] = "devDependencies";
})(VOY_FIELDS || (VOY_FIELDS = {}));
var Voy = /** @class */ (function () {
    function Voy(_a) {
        var _b = _a === void 0 ? {} : _a, _c = _b.field, field = _c === void 0 ? 'dep' : _c, _d = _b.filter, filter = _d === void 0 ? '' : _d;
        this._field = Voy.fields[field];
        this._filter = new RegExp(filter);
    }
    Object.defineProperty(Voy.prototype, "packages", {
        get: function () {
            var _a = this, _filter = _a._filter, _field = _a._field;
            var dependencies = pkg[_field];
            var dep2List = Object.keys(dependencies).map(function (pkg) { return ({ pkg: pkg, version: dependencies[pkg] }); });
            return dep2List
                .filter(function (_a) {
                var pkg = _a.pkg;
                return _filter.test(pkg);
            })
                .map(function (_a) {
                var pkg = _a.pkg, version = _a.version;
                return version ? pkg + "@" + version : pkg;
            });
        },
        enumerable: true,
        configurable: true
    });
    Voy.prototype.warn = function (packages) {
        if (packages.length === 0) {
            utils_1.color(utils_1.TEXT_COLOR.error, "nothing can be removed in " + this._field + " !");
            process.exit(0);
        }
    };
    Voy.prototype.remove = function () {
        var packages = this.packages;
        this.warn(packages);
        utils_1.color(utils_1.TEXT_COLOR.success, 'will remove packages:', packages.join('\n'));
        debug("npm rm " + packages.join(' '));
        utils_1.run('rm', packages.map(function (pkg) { return pkg.replace(/(.+)@.+/, '$1'); }));
    };
    Voy.prototype.migrate = function () {
        this.remove();
        var packages = this.packages;
        var options = this._field === 'devDependencies' ? '-S' : '-D';
        utils_1.color(utils_1.TEXT_COLOR.success, 'will add packages:', packages.join('\n'));
        debug("npm i " + packages.join(' ') + " " + options);
        utils_1.run('i', packages, options);
    };
    Voy.fields = VOY_FIELDS;
    return Voy;
}());
exports.default = (function (options) { return new Voy(options); });
